abacusai.mcp_server — AbacusAI documentation

# abacusai.mcp_server

## Classes

`McpServer` | Model Context Protocol Server

## Module Contents

class abacusai.mcp_server.McpServer(client, name=None, description=None, envVars=None, config=None, envVarInstructions=None, url=None, isActive=None, metadata=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Model Context Protocol Server

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The name of the MCP server.

    - description (str) – description of what the MCP server does.

    - envVars (list) – list of api_keys or credentials required by the MCP server.

    - config (str) – a json string containing the command and arguments for the MCP server.

    - envVarInstructions (str) – instructions for the user to get the environment variables.

    - url (str) – The url of the MCP server github repository or webpage.

    - isActive (bool) – Whether the MCP server is active.

    - metadata (dict) – additional information about the MCP server including github_stars, etc.

  name = None
  description = None
  env_vars = None
  config = None
  env_var_instructions = None
  url = None
  is_active = None
  metadata = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict